@@ -62,13 +62,28 @@ class Trajectories(JsonList):
     def __init__(self, iterable=None):
         JsonList.__init__(self, iterable, list_type=Step)
 
-    def get_step_index_by_frame(self, frame):
+    def get_step_index_by_time_stamp(self, time_stamp: float) -> int:
         if len(self) == 1:
             return 0
         m = len(self) // 2
-        if self[m] == frame:
+        if self[m].time_stamp == time_stamp:
             return m
-        if frame > self[m]:
+        if time_stamp > self[m].time_stamp:
+            return m + Trajectories.get_step_index_by_time_stamp(self[m:], time_stamp)
+        else:
+            return Trajectories.get_step_index_by_time_stamp(self[:m], time_stamp)
+
+    def get_step_by_time_stamp(self, time_stamp: float) -> Step:
+        step_index = self.get_step_index_by_time_stamp(time_stamp)
+        return self[step_index]
+
+    def get_step_index_by_frame(self, frame: int) -> int:
+        if len(self) == 1:
+            return 0
+        m = len(self) // 2
+        if self[m].frame == frame:
+            return m
+        if frame > self[m].frame:
             return m + Trajectories.get_step_index_by_frame(self[m:], frame)
         else:
             return Trajectories.get_step_index_by_frame(self[:m], frame)
@@ -164,6 +179,16 @@ class Episode(JsonObject):
             captures = JsonList(list_type=int)
         self.captures = captures
 
+    def clean(self):
+        min_time_stamp = min(self.trajectories.get_agent_trajectory("predator").where("frame", 0).get("time_stamp"))
+        new_trajectories = Trajectories()
+        for step in self.trajectories:
+            if step.frame != 0 or step.agent_name != "predator" or step.time_stamp == min_time_stamp:
+                new_trajectories.append(step)
+        self.trajectories = new_trajectories
+
+
+
 
 class Episode_list(JsonList):
     def __init__(self, iterable=None):
@@ -193,6 +218,10 @@ class Experiment(JsonObject):
             episodes = Episode_list()
         self.episodes = episodes
 
+    def clean_all_episodes (self):
+        for episode in self.episodes:
+            episode.clean()
+
     @staticmethod
     def get_from_file(file_name: str):
         e = Experiment.parse(open(file_name).read())
