@@ -3,16 +3,29 @@ import requests
 import json
 global cellworld_data_base_uri
 from datetime import datetime, timedelta
+import os
 
 cellworld_data_base_uri = "https://raw.githubusercontent.com/germanespinosa/cellworld_data/master/"
+cellworld_cache_folder = os.environ.get("CELLWORLD_CACHE")
 
 
 def get_resource(resource_type: str, key0, *argv):
     resource_uri = cellworld_data_base_uri + resource_type + "/" + key0
+    file_path = ""
+    if cellworld_cache_folder:
+        file_path = cellworld_cache_folder + "/" + resource_type + "/" + key0
     for arg in argv:
         resource_uri += "." + arg
-    response = requests.get(resource_uri)
-    return json.loads(response.text)
+        if cellworld_cache_folder:
+            file_path += "." + arg
+    if cellworld_cache_folder and os.path.exists(file_path):
+        content = ""
+        with open(file_path, "r") as text_file:
+            content = text_file.read()
+        return json.loads(content)
+    else:
+        response = requests.get(resource_uri)
+        return json.loads(response.text)
 
 
 def get_web_json(resource_uri: str):
@@ -37,7 +50,7 @@ class Time_out:
 
 
 class Timer:
-    def __init__(self, seconds:float =0):
+    def __init__(self, seconds: float = 0):
         self.time = seconds
         self.check_point = datetime.now()
 
